// Copyright (c) HashiCorp, Inc.
// SPDX-License-Identifier: MPL-2.0

package iam

import (
	"github.com/hashicorp/hcp/internal/commands/iam/groups"
	"github.com/hashicorp/hcp/internal/commands/iam/roles"
	serviceprincipals "github.com/hashicorp/hcp/internal/commands/iam/serviceprincipals"
	"github.com/hashicorp/hcp/internal/commands/iam/users"
	"github.com/hashicorp/hcp/internal/commands/iam/workloadidentityproviders"
	"github.com/hashicorp/hcp/internal/pkg/cmd"
	"github.com/hashicorp/hcp/internal/pkg/heredoc"
)

func NewCmdIam(ctx *cmd.Context) *cmd.Command {
	cmd := &cmd.Command{
		Name:      "iam",
		ShortHelp: "Manage identity and access management.",
		LongHelp: heredoc.New(ctx.IO).Must(`
		The {{ template "mdCodeOrBold" "hcp iam" }} command group lets you manage HCP identities
		including users, groups, and service principals.

		Service principal keys or workload identity providers may also be managed. When accessing
		HCP services from workloads that have an external identity provider, prefer using workload
		identity federation for more secure access to HCP.
		`),
	}

	cmd.AddChild(roles.NewCmdRoles(ctx))
	cmd.AddChild(users.NewCmdUsers(ctx))
	cmd.AddChild(groups.NewCmdGroups(ctx))
	cmd.AddChild(serviceprincipals.NewCmdServicePrincipals(ctx))
	cmd.AddChild(workloadidentityproviders.NewCmdWIPs(ctx))

	return cmd
}
