// Copyright (c) HashiCorp, Inc.
// SPDX-License-Identifier: MPL-2.0

package vaultsecrets

import (
	"github.com/hashicorp/hcp/internal/commands/vaultsecrets/apps"
	"github.com/hashicorp/hcp/internal/commands/vaultsecrets/gatewaypools"
	"github.com/hashicorp/hcp/internal/commands/vaultsecrets/integrations"
	"github.com/hashicorp/hcp/internal/commands/vaultsecrets/run"
	"github.com/hashicorp/hcp/internal/commands/vaultsecrets/secrets"
	"github.com/hashicorp/hcp/internal/pkg/cmd"
	"github.com/hashicorp/hcp/internal/pkg/heredoc"
)

func NewCmdVaultSecrets(ctx *cmd.Context) *cmd.Command {
	cmd := &cmd.Command{
		Name:      "vault-secrets",
		ShortHelp: "Manage Vault Secrets.",
		LongHelp: heredoc.New(ctx.IO).Must(`
		The {{ template "mdCodeOrBold" "hcp vault-secrets" }} command group lets you manage Vault Secrets
		resources through the CLI.
		`),
		Aliases: []string{
			"vs",
		},
	}

	cmd.AddChild(apps.NewCmdApps(ctx))
	cmd.AddChild(integrations.NewCmdIntegrations(ctx))
	cmd.AddChild(secrets.NewCmdSecrets(ctx))
	cmd.AddChild(gatewaypools.NewCmdGatewayPools(ctx))
	cmd.AddChild(run.NewCmdRun(ctx, nil))
	return cmd
}
